# Contributing Guidelines

- Fork the repo.
- Install env with `python>=3.8`, e.g., for linux run:

```bash
# install python 3.8.16, e.g, if using pyenv run:
# pyenv install 3.8.16
# pyenv local 3.8.16
$ bash .ci/install-dev.sh
$ bash .ci/install.sh

# activate env:-
$ activate .env/bin/activate
```

- Modify the code, commit the changes and create a PR.
